
MonitorWindow = class(BaseWindow);

-- Initializes a new MonitorWindow instance
function MonitorWindow:Constructor(viewModel)
	BaseWindow.Constructor(self);
	self.ViewModel = viewModel;

	local content = TemplateLoader.Setup(self, self:GetTemplate());
	self:SetContent(content);
	self:SetText(self.ViewModel.Title);
	self:FitToContent();
	self:SetMaximumSize(1000, 790);
	self:UpdateStats();

	self.ViewModel:OnPropertyChanged("Stats", function()
		self:UpdateStats();
	end);
end

function MonitorWindow:Closing(args)
	self.ViewModel:Destroy();
	BaseWindow.Closing(self, args);
end

function MonitorWindow:UpdateStats(args)
	for _, item in pairs(self.ViewModel.Stats) do
		-- the TextBlock to find
		local textBlockName = item.Name .. " - TextBlock";

		if self[textBlockName] == nil then
			-- load the stats item template and add the newly created controls to the StatsPanel
			local bindings = {["Title"] = item.Name, ["TextBlockName"] = textBlockName};
			local item = TemplateLoader.Setup(self, self:GetStatsItemTemplate(bindings));
			local control = self.StatsPanel:AddControl(item);
			control.ContentStyle.VerticalAlignment = VerticalAlignment.Center;
		end

		self[textBlockName]:SetText(item.Value);
	end

	self:Invalidate();
end

function MonitorWindow:GetTemplate(bindings)
	return {
		["Type"] = Border,
		["Width"] = 300,
		["Height"] = 200,
		["BorderWidth"] = 1,
		["Content"] = 
		{
			{
				["Type"] = Image,
				["ImageMode"] = ImageMode.KeepImage,
				["VerticalAlignment"] = VerticalAlignment.Center,
				["HorizontalAlignment"] = HorizontalAlignment.Center,
				["Background"] = Images.Monitor,
				["BlendMode"] = Turbine.UI.BlendMode.Multiply,
				["ImageBackColor"] = Turbine.UI.Color(0.98, 0.2, 0.2, 0.2),
				["Content"] = 
				{
					{
						["Type"] = ScrollViewer,
						["Content.DynamicHeight"] = 1,
						["Content.DynamicWidth"] = 1,
						["Content"] =
						{
							{
								["Type"] = StackPanel,
								["Name"] = "StatsPanel",
								["Content"] =
								{
									{
										["Type"] = StackPanel,
										["IsVertical"] = false,
										["FitToContent"] = false,
										["Content.VerticalAlignment"] = VerticalAlignment.Center,
										["Content"] =
										{
										},
									},
								},
							},
						},
					},
				},
			},
		},
	};
end

function MonitorWindow:GetStatsItemTemplate(bindings)
	return {
		["Type"] = StackPanel,
		["IsVertical"] = false,
		["FitToContent"] = false,
		["Content"] =
		{
			{
				["Type"] = TextBlock,
				["Text"] = bindings["Title"],
				["Content.DynamicWidth"] = 1,
				["Content.Padding"] = 4,
			},
			{
				["Type"] = TextBlock,
				["Name"] = bindings["TextBlockName"],
				["Content.DynamicWidth"] = 1,
				["Content.Padding"] = 4,
			},
		},
	};
end
